pub struct Delimited<D, V> { /* private fields */ }Expand description
A MakeVisitor wrapper that wraps a visitor that writes formatted output so
that a delimiter is inserted between writing formatted field values.
Implementations