MakeExt

Trait MakeExt 

pub trait MakeExt<T>
where Self: MakeVisitor<T> + Sized + Sealed<MakeExtMarker<T>>,
{ // Provided methods fn debug_alt(self) -> Alt<Self> { ... } fn display_messages(self) -> Messages<Self> { ... } fn delimited<D>(self, delimiter: D) -> Delimited<D, Self> where D: AsRef<str> + Clone, Self::Visitor: VisitFmt { ... } }
Extension trait providing MakeVisitor combinators.

Provided Methods

fn debug_alt(self) -> Alt<Self>

Wraps self so that any fmt::Debug fields are recorded using the alternate formatter ({:#?}).

fn display_messages(self) -> Messages<Self>

Wraps self so that any string fields named “message” are recorded using fmt::Display.

fn delimited<D>(self, delimiter: D) -> Delimited<D, Self>
where D: AsRef<str> + Clone, Self::Visitor: VisitFmt,

Wraps self so that when fields are formatted to a writer, they are separated by the provided delimiter.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, M> MakeExt<T> for M
where M: MakeVisitor<T> + Sized + Sealed<MakeExtMarker<T>>,