pub trait VisitOutput<Out>: Visit {
// Required method
fn finish(self) -> Out;
// Provided method
fn visit<R>(self, fields: &R) -> Out
where R: RecordFields,
Self: Sized { ... }
}Expand description
A visitor that produces output once it has visited a set of fields.
Required Methods
Provided Methods
Sourcefn visit<R>(self, fields: &R) -> Outwhere
R: RecordFields,
Self: Sized,
fn visit<R>(self, fields: &R) -> Outwhere
R: RecordFields,
Self: Sized,
Visit a set of fields, and return the output of finishing the visitor once the fields have been visited.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".