Struct tracing_subscriber::fmt::format::Compact [−][src]
pub struct Compact;This is supported on crate feature
fmt only.Expand description
Marker for Format that indicates that the compact log format should be used.
The compact format only includes the fields from the most recently entered span.