Struct tracing_subscriber::fmt::FormattedFields [−][src]
pub struct FormattedFields<E> {
pub fields: String,
// some fields omitted
}Expand description
A formatted representation of a span’s fields stored in its extensions.
Because FormattedFields is generic over the type of the formatter that
produced it, multiple versions of a span’s formatted fields can be stored in
the Extensions type-map. This means that when multiple
formatters are in use, each can store its own formatted representation
without conflicting.
Fields
fields: StringThe formatted fields of a span.
Implementations
Methods from Deref<Target = String>
Extracts a string slice containing the entire String.
Examples
Basic usage:
let s = String::from("foo");
assert_eq!("foo", s.as_str());Returns this String’s capacity, in bytes.
Examples
Basic usage:
let s = String::with_capacity(10);
assert!(s.capacity() >= 10);Returns the length of this String, in bytes, not chars or
graphemes. In other words, it might not be what a human considers the
length of the string.
Examples
Basic usage:
let a = String::from("foo");
assert_eq!(a.len(), 3);
let fancy_f = String::from("ƒoo");
assert_eq!(fancy_f.len(), 4);
assert_eq!(fancy_f.chars().count(), 3);Trait Implementations