pub struct PrettyVisitor<'a> { /* fields omitted */ }
This is supported on crate feature fmt only.
Returns a new default visitor that formats to the provided writer.
writer: the writer to format to.
is_empty: whether or not any fields have been previously written to
that writer.
Formats the value using the given formatter. Read more
Visit a value implementing fmt::Debug.
Visit a double-precision floating point value.
Visit a signed 64-bit integer value.
Visit an unsigned 64-bit integer value.
Returns the formatter that this visitor writes to.
Completes the visitor, returning any output. Read more
Visit a set of fields, and return the output of finishing the visitor
once the fields have been visited. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.