Type Alias tracing_subscriber::fmt::Formatter
source · pub type Formatter<N = DefaultFields, E = Format<Full>, W = fn() -> Stdout> = Layered<Layer<Registry, N, E, W>, Registry>;Available on crate features
fmt and std only.Expand description
A Subscriber that logs formatted representations of tracing events.
This type only logs formatted events; it does not perform any filtering.
Aliased Type
struct Formatter<N = DefaultFields, E = Format<Full>, W = fn() -> Stdout> { /* private fields */ }Implementations
sourceimpl<L, S> Layered<L, S>where
L: Layer<S>,
S: Subscriber,
impl<L, S> Layered<L, S>where
L: Layer<S>,
S: Subscriber,
sourcepub fn is<T: Any>(&self) -> bool
pub fn is<T: Any>(&self) -> bool
Returns true if this Subscriber is the same type as T.
sourcepub fn downcast_ref<T: Any>(&self) -> Option<&T> ⓘ
pub fn downcast_ref<T: Any>(&self) -> Option<&T> ⓘ
Returns some reference to this Subscriber value if it is of type T,
or None if it isn’t.